/***************************************************************************
                          tagger_oggvorbis.h  -  description
                             -------------------
    begin                : Wed May 9 2001
    copyright            : (C) 2001 by Holger Sattel
    email                : hsattel@rumms.uni-mannheim.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef TAGGER_OGGVORBIS_H
#define TAGGER_OGGVORBIS_H

#include "tagger.h"
#include <vorbis/codec.h>
#include <qstring.h>

class Tagger_OggVorbis {
public: 
	Tagger_OggVorbis();

  static bool getInfo(TRACK *track, bool lazyRead);
  static bool getTagOnly(TRACK *track);
  static bool writeInfo(TRACK *track);

	~Tagger_OggVorbis();
};

#endif
